@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic melodic ornamentation
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0602';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -69,7 +69,7 @@ sub grace_note {
 
     # Compute the ornament durations
     my $x = $MIDI::Simple::Length{$duration} * TICKS;
-    my $y = $MIDI::Simple::Length{yn} * TICKS; # Thirty-second note
+    my $y = $MIDI::Simple::Length{xn} * TICKS; # Thirty-second note
     my $z = sprintf '%0.f', $x - $y;
     print "Durations: $x, $y, $z\n" if $self->verbose;
     $y = 'd' . $y;
@@ -224,7 +224,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic melodic ornamentati
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
@@ -380,7 +380,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gene Boggs.
+This software is copyright (c) 2021 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
